##  Editing S-User ID Authorizations
### Context
You may want to edit an S-user’s authorizations if the permissions they currently have are insufficient for performing their role. You can grant or restrict access to specific functions and fine-tune their access by setting appropriate authorization levels.
### Procedure
  1. Go to SAP for Me.
  2. In the User Management area, go to Home > Users & Contacts > User Management.
  3. Choose a user’s name to open their details.
  4. Open the Authorizations tab in the user details window. Choose the edit (pencil) icon to begin editing.
  5. Select the desired authorizations.
  6. Optional: Adjust the authorization level for granular control, such as restricting case creation to a specific installation number.
By default, authorizations are granted at the global level for all customer numbers and installations.
  7. Choose Save.
